summaryrefslogtreecommitdiff
path: root/scripts
diff options
context:
space:
mode:
authorLuke Shumaker <lukeshu@lukeshu.com>2023-03-07 01:35:08 -0700
committerLuke Shumaker <lukeshu@lukeshu.com>2023-03-14 21:31:45 -0600
commit4278c185aafb0fb197e52cdb9eb9bd9d36b61c4d (patch)
tree865db7f28999b5ad71a9805b4b5bfa49f515957e /scripts
parent7c9ea276ac69130229f4ae35547288fe8429f6f1 (diff)
cmd/btrfs-rec: Smash scandevices and rebuild-mappings together
Diffstat (limited to 'scripts')
-rwxr-xr-xscripts/main.sh8
1 files changed, 4 insertions, 4 deletions
diff --git a/scripts/main.sh b/scripts/main.sh
index 4aa96ea..67fb330 100755
--- a/scripts/main.sh
+++ b/scripts/main.sh
@@ -32,9 +32,9 @@ export GOMEMLIMIT="$(awk '/^MemTotal:/{ print $2 "KiB" }' </proc/meminfo)"
######################################################################
run-btrfs-rec $gendir/0.scandevices.json \
- inspect scandevices
+ inspect rebuild-mappings scan
run-btrfs-rec $gendir/1.mappings.json \
- inspect rebuild-mappings $gendir/0.scandevices.json
+ inspect rebuild-mappings process $gendir/0.scandevices.json
# 1.mappings.log says:
#
@@ -52,13 +52,13 @@ run-btrfs-rec $gendir/1.mappings.json \
# matter which order we put the 2 block groups in within that physical
# region. So just put them in laddr order.
#
# And then run that through `rebuild-mappings` again to fill in the
# flags and normalize it.
run-btrfs-rec $gendir/2.mappings.json \
--mappings=<(sed <$gendir/1.mappings.json \
-e '2a{"LAddr":5242880,"PAddr":{"Dev":1,"Addr":5242880},"Size":1},' \
-e '2a{"LAddr":13631488,"PAddr":{"Dev":1,"Addr":13631488},"Size":1},') \
- inspect rebuild-mappings $gendir/0.scandevices.json
+ inspect rebuild-mappings process $gendir/0.scandevices.json
run-btrfs-rec $gendir/3.nodes.json \
--mappings=$gendir/2.mappings.json \
@@ -52,13 +52,13 @@ run-btrfs-rec $gendir/1.mappings.json \
# region. So just put them in laddr order.
#
-# And then run that through `rebuild-mappings` again to fill in the
+# And then run that through `rebuild-mappings process` again to fill in the
# flags and normalize it.
run-btrfs-rec $gendir/2.mappings.json \